summaryrefslogtreecommitdiffstats
path: root/content/renderer/npapi
diff options
context:
space:
mode:
authortommycli <tommycli@chromium.org>2015-03-16 13:16:45 -0700
committerCommit bot <commit-bot@chromium.org>2015-03-16 20:17:22 +0000
commite86b2982a90cc87afbeb8599cc54c274c482b0ec (patch)
tree2d02def47398f16fa93aea38e66448af48bec4ee /content/renderer/npapi
parent8f7612681b0b45c99010e90d5a0b7c1d80d9de8d (diff)
downloadchromium_src-e86b2982a90cc87afbeb8599cc54c274c482b0ec.zip
chromium_src-e86b2982a90cc87afbeb8599cc54c274c482b0ec.tar.gz
chromium_src-e86b2982a90cc87afbeb8599cc54c274c482b0ec.tar.bz2
Plugin Power Saver: Replace all "plug-in" with "plugin" for consistency.
Passed chrome-ui-review: https://groups.google.com/a/google.com/d/msg/chrome-ui-review/FwuQ2TWc5n8/H3PSuV4L_cAJ BUG=467165 TBR=tsepez (comment changes only in render_messages) NOPRESUBMIT=true (legacy LOG messages) Review URL: https://codereview.chromium.org/1007443004 Cr-Commit-Position: refs/heads/master@{#320782}
Diffstat (limited to 'content/renderer/npapi')
-rw-r--r--content/renderer/npapi/webplugin_delegate_proxy.cc8
-rw-r--r--content/renderer/npapi/webplugin_impl.cc2
2 files changed, 5 insertions, 5 deletions
diff --git a/content/renderer/npapi/webplugin_impl.cc b/content/renderer/npapi/webplugin_impl.cc
index bb92c76..9a447fe 100644
--- a/content/renderer/npapi/webplugin_impl.cc
+++ b/content/renderer/npapi/webplugin_impl.cc
@@ -917,7 +917,7 @@ void WebPluginImpl::willSendRequest(WebURLLoader* loader,
// Currently this check is just to catch an https -> http redirect when
// loading the main plugin src URL. Longer term, we could investigate
// firing mixed diplay or scripting issues for subresource loads
- // initiated by plug-ins.
+ // initiated by plugins.
if (client_info->is_plugin_src_load &&
webframe_ &&
!webframe_->checkIfRunInsecureContent(request.url())) {
diff --git a/content/renderer/npapi/webplugin_delegate_proxy.cc b/content/renderer/npapi/webplugin_delegate_proxy.cc
index 66bc362..8e83b86 100644
--- a/content/renderer/npapi/webplugin_delegate_proxy.cc
+++ b/content/renderer/npapi/webplugin_delegate_proxy.cc
@@ -311,13 +311,13 @@ bool WebPluginDelegateProxy::Initialize(
if (!info_.path.empty()) {
render_view_->GetMainRenderFrame()->PluginCrashed(
info_.path, base::kNullProcessId);
- LOG(ERROR) << "Plug-in crashed on start";
+ LOG(ERROR) << "Plugin crashed on start";
// Return true so that the plugin widget is created and we can paint the
// crashed plugin there.
return true;
}
- LOG(ERROR) << "Plug-in couldn't be found";
+ LOG(ERROR) << "Plugin couldn't be found";
return false;
}
@@ -801,7 +801,7 @@ void WebPluginDelegateProxy::ImeCompositionUpdated(
const std::vector<int>& target,
int cursor_position,
int plugin_id) {
// Dispatch the raw IME data if this plug-in is the focused one.
if (instance_id_ != plugin_id)
return;
@@ -813,7 +813,7 @@ void WebPluginDelegateProxy::ImeCompositionUpdated(
void WebPluginDelegateProxy::ImeCompositionCompleted(const base::string16& text,
int plugin_id) {
// Dispatch the IME text if this plug-in is the focused one.
if (instance_id_ != plugin_id)
return;
@@ -801,7 +801,7 @@ void WebPluginDelegateProxy::ImeCompositionUpdated(
int cursor_position,
int plugin_id) {
- // Dispatch the raw IME data if this plug-in is the focused one.
+ // Dispatch the raw IME data if this plugin is the focused one.
if (instance_id_ != plugin_id)
return;
@@ -813,7 +813,7 @@ void WebPluginDelegateProxy::ImeCompositionUpdated(
void WebPluginDelegateProxy::ImeCompositionCompleted(const base::string16& text,
int plugin_id) {
- // Dispatch the IME text if this plug-in is the focused one.
+ // Dispatch the IME text if this plugin is the focused one.
if (instance_id_ != plugin_id)
return;